/**
 * JASMINe Deploy ME [Managed Element]
 * Copyright (C) 2012 Bull S.A.S.
 * Copyright (C) 2012 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ICommandLine.java 9961 2012-03-26 08:27:33Z cazauxj $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.deployme.api;

/**
 * Represent the command line arguments
 * @author Jeremy Cazaux
 */
public interface ICommandLine {

    public static final String ERROR_TOPOLOGY_NOT_SET = "The 'topologyFile' option is mandatory";

    public static final String ERROR_NO_OPTIONS = "No options set. You must set one of the 'machineName', 'domainName', 'clusterName'"
            + " or 'serverName' options";

    public static final String ERROR_SERVER_CLUSTER_DOMAIN = "One of the 'serverName' or 'clusterName' options must be set when the"
            + " 'domainName' option is set";

    public static final String ERROR_DOMAIN_SERVER_CLUSTER = "The 'clusterName' and 'serverName' options require the 'domainName' "
            + "to be set";

    public static final String ERROR_CLUSTER_SERVER = "Only one of the 'clusterName' and 'serverName' options must be set";

    public static final String ERROR_MACHINE_DOMAIN_SERVER_CLUSTER = "The 'machineName' option must not be set when one of the "
            + "'clusterName', 'domainName' or 'serverName' options are set";

    /**
     * key word to define verbose mode on the command line. Use associated with
     * addValue()
     */
    public static final String COMMAND_OPTION_VERBOSE = "verbose";

    /**
     * key word to define server name on the command line. Use associated with
     * addValue()
     */
    public static final String COMMAND_OPTION_SERVER_NAME = "serverName";

    /**
     * key word to define domain name on the command line. Use associated with
     * addValue()
     */
    public static final String COMMAND_OPTION_DOMAIN_NAME = "domainName";

    /**
     * key word to define machine name on the command line. Use associated with
     * addValue()
     */
    public static final String COMMAND_OPTION_MACHINE_NAME = "machineName";

    /**
     * key word to define cluster name on the command line. Use associated with
     * addValue()
     */
    public static final String COMMAND_OPTION_CLUSTER_NAME = "clusterName";

    /**
     * key word to define topology file name on the command line. Use associated
     * with addValue()
     */
    public static final String COMMAND_OPTION_TOPOLOGY_FILE = "topologyFile";

    /**
     * Record a value of the command line.
     *
     * @param argName Name of the value to record
     * @param argValue Value to record
     */
    void addValue(final String argName, final String argValue);


    /**
     * return if verbose
     *
     * @return if verbose
     */
     boolean getVerbose();

    /**
     * return the topologyFile
     *
     * @return the topologyFile
     */
    String getTopologyFile();

    /**
     * return the serverName
     *
     * @return the serverName
     */
    String getServerName();

    /**
     * return the domainName
     *
     * @return the domainName
     */
    String getDomainName();

    /**
     * return the machineName
     *
     * @return the machineName
     */
    String getMachineName();

    /**
     * @return the clusterName
     */
    String getClusterName();

    /**
     * Check if the command line contains all what we need
     */
    void checkCommandLine();
}
