/**
 * JASMINe Deploy ME [Managed Element]
 * Copyright (C) 2012 Bull S.A.S.
 * Copyright (C) 2012 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IDeployMeService.java 10002 2012-05-02 15:51:23Z cazauxj $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.deployme.api;

import org.xml.sax.SAXException;

import javax.xml.bind.JAXBException;
import java.io.IOException;
import java.net.URL;
import org.ow2.jasmine.deployme.v1.generated.Topology.Domains.Domain.Servers.Server;

/**
 * Manage deployment of  topology
 * @author Jeremy Cazaux
 */
public interface IDeployMeService {

    /**
     * Deploy a configuration : <br />
     * - Load the topology <br />
     * - Apply the config of the servers(machine or domain/server/cluster)
     *
     * @param topologyUrl topology xml file to use url
     * @param machine The machine to use. if set domain or server or cluster
     *        name must not be set
     * @param domain The domain where found the server to use. If set, server or
     *        cluster has to be set, and machine must no be set
     * @param server The server to use. If set, domain has to be set and cluster
     *        or machine must not be set
     * @param cluster The cluster daemon to use. If set, domain has to be set
     *        and server or machine must not be set
     * @throws javax.xml.bind.JAXBException JAXB exception.
     * @throws org.xml.sax.SAXException SAX exception.
     * @throws java.io.IOException If topologyUrl cannot be retrieved.
     */
    void deploy(final URL topologyUrl, final String machine, final String domain, final String server, final String cluster)
            throws SAXException, JAXBException, IOException;

    /**
     * Deploy a configuration : <br />
     * - Load the topology <br />
     * - Apply the config of the servers(machine or domain/server/cluster)
     *
     * @param topologyXml topology xml string
     * @param machine The machine to use. if set domain or server or cluster
     *        name must not be set
     * @param domain The domain where found the server to use. If set, server or
     *        cluster has to be set, and machine must no be set
     * @param server The server to use. If set, domain has to be set and cluster
     *        or machine must not be set
     * @param cluster The cluster daemon to use. If set, domain has to be set
     *        and server or machine must not be set
     * @throws javax.xml.bind.JAXBException JAXB exception.
     * @throws org.xml.sax.SAXException SAX exception.
     * @throws java.io.IOException If topologyUrl cannot be retrieved.
     */
    void deploy(final String topologyXml, final String machine, final String domain, final String server,
                final String cluster) throws SAXException, JAXBException, IOException;

    /**
     * @return the deployme instance
     */
    IDeployme getInstance();

    /**
     * @param domainName The name of the domain
     * @param serverName The name of the server
     * @return the {@link IServer}
     */
    IServer getServer(final String domainName, final String serverName);
}
